@@ -2,23 +2,22 @@
  * probe.c
  * Copyright 2009-2010 John Lindgren
  *
- * This file is part of Audacious.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Audacious is free software: you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation, version 2 or version 3 of the License.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * You should have received a copy of the GNU General Public License along with
- * Audacious. If not, see <http://www.gnu.org/licenses/>.
- *
- * The Audacious team does not consider modular code linking to Audacious or
- * using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
+#include <glib.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -33,20 +32,22 @@
 
 typedef struct
 {
-    gchar * filename;
+    const char * filename;
     VFSFile * handle;
-    gboolean buffered;
+    bool_t failed;
     PluginHandle * plugin;
 }
 ProbeState;
 
-static gboolean check_opened (ProbeState * state)
+static bool_t check_opened (ProbeState * state)
 {
     if (state->handle != NULL)
         return TRUE;
+    if (state->failed)
+        return FALSE;
 
     AUDDBG ("Opening %s.\n", state->filename);
-    if ((state->buffered = vfs_is_remote (state->filename)))
+    if (vfs_is_remote (state->filename))
         state->handle = probe_buffer_new (state->filename);
     else
         state->handle = vfs_fopen (state->filename, "r");
@@ -55,10 +56,11 @@ static gboolean check_opened (ProbeState * state)
         return TRUE;
 
     AUDDBG ("FAILED.\n");
+    state->failed = TRUE;
     return FALSE;
 }
 
-static gboolean probe_func (PluginHandle * plugin, ProbeState * state)
+static bool_t probe_func (PluginHandle * plugin, ProbeState * state)
 {
     AUDDBG ("Trying %s.\n", plugin_get_name (plugin));
     InputPlugin * decoder = plugin_get_header (plugin);
@@ -70,9 +72,6 @@ static gboolean probe_func (PluginHandle * plugin, ProbeState * state)
         if (! check_opened (state))
             return FALSE;
 
-        if (state->buffered)
-            probe_buffer_set_decoder (state->handle, plugin_get_name (plugin));
-
         if (decoder->is_our_file_from_vfs (state->filename, state->handle))
         {
             state->plugin = plugin;
@@ -82,14 +81,6 @@ static gboolean probe_func (PluginHandle * plugin, ProbeState * state)
         if (vfs_fseek (state->handle, 0, SEEK_SET) < 0)
             return FALSE;
     }
-    else if (decoder->is_our_file != NULL)
-    {
-        if (decoder->is_our_file (state->filename))
-        {
-            state->plugin = plugin;
-            return FALSE;
-        }
-    }
 
     return TRUE;
 }
@@ -106,7 +97,7 @@ static gboolean probe_func (PluginHandle * plugin, ProbeState * state)
  *    similarly that the plugin passed in this call is the last one.
  */
 
-static gboolean probe_func_fast (PluginHandle * plugin, ProbeState * state)
+static bool_t probe_func_fast (PluginHandle * plugin, ProbeState * state)
 {
     if (state->plugin != NULL)
     {
@@ -124,42 +115,32 @@ static gboolean probe_func_fast (PluginHandle * plugin, ProbeState * state)
 
 static void probe_by_scheme (ProbeState * state)
 {
-    gchar * s = strstr (state->filename, "://");
-    gchar c;
+    const char * s = strstr (state->filename, "://");
 
     if (s == NULL)
         return;
 
     AUDDBG ("Probing by scheme.\n");
-    c = s[3];
-    s[3] = 0;
-    input_plugin_for_key (INPUT_KEY_SCHEME, state->filename, (PluginForEachFunc)
-     probe_func_fast, state);
-    s[3] = c;
+    char buf[s - state->filename + 1];
+    memcpy (buf, state->filename, s - state->filename);
+    buf[s - state->filename] = 0;
+
+    input_plugin_for_key (INPUT_KEY_SCHEME, buf, (PluginForEachFunc) probe_func_fast, state);
 }
 
 static void probe_by_extension (ProbeState * state)
 {
-    gchar * s = strrchr (state->filename, '.');
-
-    if (s == NULL)
+    char buf[32];
+    if (! uri_get_extension (state->filename, buf, sizeof buf))
         return;
 
     AUDDBG ("Probing by extension.\n");
-    s = g_ascii_strdown (s + 1, -1);
-
-    gchar * q = strrchr (s, '?');
-    if (q != NULL)
-        * q = 0;
-
-    input_plugin_for_key (INPUT_KEY_EXTENSION, s, (PluginForEachFunc)
-     probe_func_fast, state);
-    g_free (s);
+    input_plugin_for_key (INPUT_KEY_EXTENSION, buf, (PluginForEachFunc) probe_func_fast, state);
 }
 
 static void probe_by_mime (ProbeState * state)
 {
-    gchar * mime;
+    char * mime;
 
     if (! check_opened (state))
         return;
@@ -176,17 +157,18 @@ static void probe_by_mime (ProbeState * state)
 static void probe_by_content (ProbeState * state)
 {
     AUDDBG ("Probing by content.\n");
-    plugin_for_each (PLUGIN_TYPE_INPUT, (PluginForEachFunc) probe_func, state);
+    plugin_for_enabled (PLUGIN_TYPE_INPUT, (PluginForEachFunc) probe_func, state);
 }
 
-InputPlugin * file_find_decoder (const gchar * filename, gboolean fast)
+PluginHandle * file_find_decoder (const char * filename, bool_t fast)
 {
     ProbeState state;
 
     AUDDBG ("Probing %s.\n", filename);
     state.plugin = NULL;
-    state.filename = filename_split_subtune (filename, NULL);
+    state.filename = filename;
     state.handle = NULL;
+    state.failed = FALSE;
 
     probe_by_scheme (& state);
 
@@ -206,74 +188,73 @@ InputPlugin * file_find_decoder (const gchar * filename, gboolean fast)
     probe_by_content (& state);
 
 DONE:
-    g_free (state.filename);
-
     if (state.handle != NULL)
         vfs_fclose (state.handle);
 
-    return (state.plugin != NULL) ? plugin_get_header (state.plugin) : NULL;
+    return state.plugin;
 }
 
-Tuple * file_read_tuple (const gchar * filename, InputPlugin * decoder)
+Tuple * file_read_tuple (const char * filename, PluginHandle * decoder)
 {
-    if (decoder->get_song_tuple != NULL)
-        return decoder->get_song_tuple (filename);
+    InputPlugin * ip = plugin_get_header (decoder);
+    g_return_val_if_fail (ip, NULL);
+    g_return_val_if_fail (ip->probe_for_tuple, NULL);
 
-    if (decoder->probe_for_tuple != NULL)
-    {
-        VFSFile * handle = vfs_fopen (filename, "r");
-        Tuple * tuple;
+    VFSFile * handle = vfs_fopen (filename, "r");
+    Tuple * tuple = ip->probe_for_tuple (filename, handle);
 
-        if (handle == NULL)
-            return NULL;
-
-        tuple = decoder->probe_for_tuple (filename, handle);
+    if (handle)
         vfs_fclose (handle);
-        return tuple;
-    }
 
-    return NULL;
+    return tuple;
 }
 
-gboolean file_read_image (const gchar * filename, InputPlugin * decoder,
- void * * data, gint * size)
+bool_t file_read_image (const char * filename, PluginHandle * decoder,
+ void * * data, int64_t * size)
 {
-    VFSFile * handle;
-    gboolean success;
-
-    if (decoder->get_song_image == NULL)
+    if (! input_plugin_has_images (decoder))
         return FALSE;
 
-    handle = vfs_fopen (filename, "r");
-    success = decoder->get_song_image (filename, handle, data, size);
+    InputPlugin * ip = plugin_get_header (decoder);
+    g_return_val_if_fail (ip, FALSE);
+    g_return_val_if_fail (ip->get_song_image, FALSE);
 
-    if (handle != NULL)
+    VFSFile * handle = vfs_fopen (filename, "r");
+    bool_t success = ip->get_song_image (filename, handle, data, size);
+
+    if (handle)
         vfs_fclose (handle);
 
+    if (! success)
+    {
+        * data = NULL;
+        * size = 0;
+    }
+
     return success;
 }
 
-gboolean file_can_write_tuple (const gchar * filename, InputPlugin * decoder)
+bool_t file_can_write_tuple (const char * filename, PluginHandle * decoder)
 {
-    return (decoder->update_song_tuple != NULL);
+    return input_plugin_can_write_tuple (decoder);
 }
 
-gboolean file_write_tuple (const gchar * filename, InputPlugin * decoder,
+bool_t file_write_tuple (const char * filename, PluginHandle * decoder,
  const Tuple * tuple)
 {
-    VFSFile * handle;
-    gboolean success;
+    InputPlugin * ip = plugin_get_header (decoder);
+    g_return_val_if_fail (ip, FALSE);
+    g_return_val_if_fail (ip->update_song_tuple, FALSE);
 
-    if (decoder->update_song_tuple == NULL)
+    VFSFile * handle = vfs_fopen (filename, "r+");
+
+    if (! handle)
         return FALSE;
 
-    handle = vfs_fopen (filename, "r+");
+    bool_t success = ip->update_song_tuple (tuple, handle);
 
-    if (handle == NULL)
-        return FALSE;
-
-    success = decoder->update_song_tuple (tuple, handle);
-    vfs_fclose (handle);
+    if (handle)
+        vfs_fclose (handle);
 
     if (success)
         playlist_rescan_file (filename);
@@ -281,11 +262,15 @@ gboolean file_write_tuple (const gchar * filename, InputPlugin * decoder,
     return success;
 }
 
-gboolean custom_infowin (const gchar * filename, InputPlugin * decoder)
+bool_t custom_infowin (const char * filename, PluginHandle * decoder)
 {
-    if (decoder->file_info_box == NULL)
+    if (! input_plugin_has_infowin (decoder))
         return FALSE;
 
-    decoder->file_info_box (filename);
+    InputPlugin * ip = plugin_get_header (decoder);
+    g_return_val_if_fail (ip, FALSE);
+    g_return_val_if_fail (ip->file_info_box, FALSE);
+
+    ip->file_info_box (filename);
     return TRUE;
 }
