@@ -1,37 +1,33 @@
 /*
- * Audacious: A cross-platform multimedia player
- * Copyright (c) 2007 William Pitcock, Tony Vroon, George Averill,
- *                    Giacomo Lozito, Derek Pomery and Yoshiki Yazawa.
+ * ui_albumart.c
+ * Copyright 2006 Michael Hanselmann and Yoshiki Yazawa
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; under version 3 of the License.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses>.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * The Audacious team does not consider modular code linking to
- * Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #include <glib.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
 #include <libaudcore/audstrings.h>
 
-#include "audconfig.h"
 #include "config.h"
 #include "i18n.h"
 #include "misc.h"
 
-static gboolean
-has_front_cover_extension(const gchar *name)
+static bool_t
+has_front_cover_extension(const char *name)
 {
     char *ext;
 
@@ -41,35 +37,31 @@ has_front_cover_extension(const gchar *name)
         return FALSE;
     }
 
-    return g_strcasecmp(ext, ".jpg") == 0 ||
-           g_strcasecmp(ext, ".jpeg") == 0 ||
-           g_strcasecmp(ext, ".png") == 0;
+    return g_ascii_strcasecmp(ext, ".jpg") == 0 ||
+           g_ascii_strcasecmp(ext, ".jpeg") == 0 ||
+           g_ascii_strcasecmp(ext, ".png") == 0;
 }
 
-static gboolean
-cover_name_filter(const gchar *name, const gchar *filter, const gboolean ret_on_empty)
+static bool_t
+cover_name_filter(const char *name, const char *filter, const bool_t ret_on_empty)
 {
-    gboolean result = FALSE;
-    gchar **splitted;
-    gchar *current;
-    gchar *lname;
-    gint i;
+    bool_t result = FALSE;
+    char **splitted;
+    char *current;
+    char *lname;
+    int i;
 
     if (!filter || strlen(filter) == 0) {
         return ret_on_empty;
     }
 
     splitted = g_strsplit(filter, ",", 0);
+    lname = g_ascii_strdown (name, -1);
 
-    lname = g_strdup(name);
-    g_strdown(lname);
-
-    for (i = 0; !result && (current = splitted[i]); i++) {
-        gchar *stripped = g_strstrip(g_strdup(current));
-        g_strdown(stripped);
-
+    for (i = 0; ! result && (current = splitted[i]); i ++)
+    {
+        char * stripped = g_strstrip (g_ascii_strdown (current, -1));
         result = result || strstr(lname, stripped);
-
         g_free(stripped);
     }
 
@@ -80,15 +72,19 @@ cover_name_filter(const gchar *name, const gchar *filter, const gboolean ret_on_
 }
 
 /* Check wether it's an image we want */
-static gboolean
-is_front_cover_image(const gchar *imgfile)
+static bool_t is_front_cover_image (const char * file)
 {
-    return cover_name_filter(imgfile, cfg.cover_name_include, TRUE) &&
-           !cover_name_filter(imgfile, cfg.cover_name_exclude, FALSE);
+    char * include = get_string (NULL, "cover_name_include");
+    char * exclude = get_string (NULL, "cover_name_exclude");
+    bool_t accept = cover_name_filter (file, include, TRUE) &&
+     ! cover_name_filter (file, exclude, FALSE);
+    g_free (include);
+    g_free (exclude);
+    return accept;
 }
 
-static gboolean
-is_file_image(const gchar *imgfile, const gchar *file_name)
+static bool_t
+is_file_image(const char *imgfile, const char *file_name)
 {
     char *imgfile_ext, *file_name_ext;
     size_t imgfile_len, file_name_len;
@@ -115,23 +111,24 @@ is_file_image(const gchar *imgfile, const gchar *file_name)
     }
 }
 
-static gchar * fileinfo_recursive_get_image (const gchar * path, const gchar *
- file_name, gint depth)
+static char * fileinfo_recursive_get_image (const char * path, const char *
+ file_name, int depth)
 {
     GDir *d;
 
-    if (cfg.recurse_for_cover && depth > cfg.recurse_for_cover_depth)
+    if (get_bool (NULL, "recurse_for_cover") && depth > get_int (NULL, "recurse_for_cover_depth"))
         return NULL;
 
     d = g_dir_open(path, 0, NULL);
 
     if (d) {
-        const gchar *f;
+        const char *f;
 
-        if (cfg.use_file_cover && file_name) {
+        if (get_bool (NULL, "use_file_cover") && file_name)
+        {
             /* Look for images matching file name */
             while((f = g_dir_read_name(d))) {
-                gchar *newpath = g_strconcat(path, "/", f, NULL);
+                char *newpath = g_strconcat(path, "/", f, NULL);
 
                 if (!g_file_test(newpath, G_FILE_TEST_IS_DIR) &&
                     has_front_cover_extension(f) &&
@@ -147,7 +144,7 @@ static gchar * fileinfo_recursive_get_image (const gchar * path, const gchar *
 
         /* Search for files using filter */
         while ((f = g_dir_read_name(d))) {
-            gchar *newpath = g_strconcat(path, "/", f, NULL);
+            char *newpath = g_strconcat(path, "/", f, NULL);
 
             if (!g_file_test(newpath, G_FILE_TEST_IS_DIR) &&
                 has_front_cover_extension(f) &&
@@ -161,17 +158,18 @@ static gchar * fileinfo_recursive_get_image (const gchar * path, const gchar *
         g_dir_rewind(d);
 
         /* checks whether recursive or not. */
-        if (!cfg.recurse_for_cover) {
+        if (! get_bool (NULL, "recurse_for_cover"))
+        {
             g_dir_close(d);
             return NULL;
         }
 
         /* Descend into directories recursively. */
         while ((f = g_dir_read_name(d))) {
-            gchar *newpath = g_strconcat(path, "/", f, NULL);
+            char *newpath = g_strconcat(path, "/", f, NULL);
 
             if(g_file_test(newpath, G_FILE_TEST_IS_DIR)) {
-                gchar *tmp = fileinfo_recursive_get_image(newpath,
+                char *tmp = fileinfo_recursive_get_image(newpath,
                     NULL, depth + 1);
                 if(tmp) {
                     g_free(newpath);
@@ -189,18 +187,18 @@ static gchar * fileinfo_recursive_get_image (const gchar * path, const gchar *
     return NULL;
 }
 
-gchar * get_associated_image_file (const gchar * filename)
+char * get_associated_image_file (const char * filename)
 {
     if (strncmp (filename, "file://", 7))
         return NULL;
 
-    gchar * unesc = uri_to_filename (filename);
+    char * unesc = uri_to_filename (filename);
     if (! unesc)
         return NULL;
 
-    gchar * path = g_path_get_dirname (unesc);
-    gchar * base = g_path_get_basename (unesc);
-    gchar * image_file = fileinfo_recursive_get_image (path, base, 0);
+    char * path = g_path_get_dirname (unesc);
+    char * base = g_path_get_basename (unesc);
+    char * image_file = fileinfo_recursive_get_image (path, base, 0);
 
     g_free (unesc);
     g_free (path);
